﻿using System;
using Wisej.Web;
using Acclaro.WisejEJ2Charts.AccumulationChartDefinition;
using System.Collections.Generic;

namespace Acclaro.WisejEJ2Charts
{
	public partial class EJ2AccumulationChart : Wisej.Web.UserControl
	{
		public EJ2AccumulationChartOptions _options { get; private set; }

		public EJ2AccumulationChart(string title, IEnumerable<string> sliceNames, IEnumerable<int> sliceValues, IEnumerable<int> sliceRadiuses = null)
		{
			InitializeComponent();

			_options = new EJ2AccumulationChartOptions() { title = title };
			_options.series[0] = new Series() { xName = "x", yName = "y" };

			Series s = _options.series[0];

			s.dataSource.Clear();

			IEnumerator<int> sliceRadiusIterator = null;
			if (sliceRadiuses != null)
			{
				s.radius = "r";
				sliceRadiusIterator = sliceRadiuses.GetEnumerator();
			}
			var sliceNameIterator = sliceNames.GetEnumerator();
			var sliceValueIterator = sliceValues.GetEnumerator();
			while (sliceNameIterator.MoveNext())
			{
				if (!sliceValueIterator.MoveNext()) break;
				var data = new Data() { x = sliceNameIterator.Current, y = sliceValueIterator.Current };
				if (sliceRadiusIterator != null && sliceRadiusIterator.MoveNext())
				{
					data.r = sliceRadiusIterator.Current.ToString() + "%";
				}
				s.dataSource.Add(data);
			}
		}

		public void Commit()
		{
			string json = _options.ToJSON(Wisej.Core.WisejSerializerOptions.IgnoreNulls);
			this.accumulationChart1.Options = Wisej.Core.WisejSerializer.Parse(json);
		}

		public Center SetCenter(int? x, int? y)
		{
			if (x == null && y == null)
			{
				_options.center = null;
			}
			else
			{
				if (_options.center == null) _options.center = new Center();

				if (x != null)
				{
					_options.center.x = x.ToString() + "%";
				}

				if (y != null)
				{
					_options.center.y = y.ToString() + "%";
				}
			}

			return _options.center;
		}

		public void SetInnerRadius(int percent)
		{
			_options.series[0].innerRadius = percent.ToString() + "%";
		}

		public DataLabel SetDataLabelSettings(bool? visible, bool? positionInside)
		{
			DataLabel dl = new DataLabel() { name = "x", visible = visible };

			switch (positionInside)
			{
				case true:
					dl.position = "Inside";
					break;
				case false:
					dl.position = "Outside";
					break;
				default:
					dl.position = null;
					break;
			}

			_options.series[0].dataLabel = dl;
			return dl;
		}
	}
}
